﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Diagnostics;
using Infragistics.Windows.DataPresenter.Events;
using System.Windows.Input;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;

namespace XamDataGridInteraction
{
    public class ViewModel : INotifyPropertyChanged
    {
        private Person _activePerson;
        public Person ActivePerson
        {
            get { return _activePerson; }
            set
            {
                _activePerson = value;
                NotifyPropertyChanged("ActivePerson");
            }
        }

        private ObservableCollection<Person> _people;
        public ObservableCollection<Person> People
        {
            get { return _people; }
            set
            {
                _people = value;
                NotifyPropertyChanged("People");
            }
        }

        public ICommand DeleteCommand { get; set; }

        public ViewModel()
        {
            People = new ObservableCollection<Person>();
            People.Add(new Person() { Id = 1, LastName = "Doe" });
            People.Add(new Person() { Id = 3, LastName = "Doe", Age = 34.5555 });
            People.Add(new Person() { Id = 2, LastName = "Doe", Age = 56 });
            People.Add(new Person() { Id = 4, LastName = "Smith", Age = 23 });

            DeleteCommand = new DelegateCommand(Delete, CanDelete);
        }

        public void Delete(object parameter)
        {
            var result = MessageBox.Show(String.Format("Are you sure you want to delete {0}", ActivePerson.LastName), "Delete Person", MessageBoxButton.YesNo);
            if (result == MessageBoxResult.Yes)
            {
                People.Remove(ActivePerson);
            }
        }

        public bool CanDelete(object parameter)
        {
            return ActivePerson != null;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
